==> com.liferay.sharing.web-1.0.65.jar: META-INF/resources/SharedAssets.es.js <==
Liferay.Loader.define("sharing-web@1.0.65/SharedAssets.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var SharedAssets = /*#__PURE__*/function (_PortletBase) {
    _inherits(SharedAssets, _PortletBase);

    function SharedAssets(config) {
      var _getPrototypeOf2;

      var _this;

      _classCallCheck(this, SharedAssets);

      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(SharedAssets)).call.apply(_getPrototypeOf2, [this, config].concat(args)));
      _this._selectAssetTypeURL = config.selectAssetTypeURL;
      _this._viewAssetTypeURL = config.viewAssetTypeURL;
      return _this;
    }

    _createClass(SharedAssets, [{
      key: "handleFilterItemClicked",
      value: function handleFilterItemClicked(event) {
        var itemData = event.data.item.data;
        var namespace = this.namespace;
        var viewAssetTypeURL = this._viewAssetTypeURL;

        if (itemData.action === 'openAssetTypesSelector') {
          var itemSelectorDialog = new _frontendJsWeb.ItemSelectorDialog({
            buttonAddLabel: Liferay.Language.get('select'),
            eventName: namespace + 'selectAssetType',
            title: Liferay.Language.get('select-asset-type'),
            url: this._selectAssetTypeURL
          });
          itemSelectorDialog.open();
          itemSelectorDialog.on('selectedItemChange', function (event) {
            var selectedItem = event.selectedItem;

            if (selectedItem) {
              var uri = viewAssetTypeURL;
              uri = Liferay.Util.addParams(namespace + 'className=' + selectedItem, uri);
              location.href = uri;
            }
          });
        }
      }
    }]);

    return SharedAssets;
  }(_frontendJsWeb.PortletBase);

  var _default = SharedAssets;
  exports["default"] = _default;
  //# sourceMappingURL=SharedAssets.es.js.map
});
//# sourceMappingURL=SharedAssets.es.js.map

==> com.liferay.sharing.web-2.0.18.jar: META-INF/resources/SharedAssets.es.js <==
Liferay.Loader.define("sharing-web@2.0.18/SharedAssets.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var SharedAssets =
  /*#__PURE__*/
  function (_PortletBase) {
    _inherits(SharedAssets, _PortletBase);

    function SharedAssets(config) {
      var _getPrototypeOf2;

      var _this;

      _classCallCheck(this, SharedAssets);

      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(SharedAssets)).call.apply(_getPrototypeOf2, [this, config].concat(args)));
      _this._selectAssetTypeURL = config.selectAssetTypeURL;
      _this._viewAssetTypeURL = config.viewAssetTypeURL;
      return _this;
    }

    _createClass(SharedAssets, [{
      key: "attached",
      value: function attached() {
        var _this2 = this;

        Liferay.on('sharing:changed', function () {
          return Liferay.Portlet.refresh('#p_p_id' + _this2.namespace);
        });
      }
    }, {
      key: "handleFilterItemClicked",
      value: function handleFilterItemClicked(event) {
        var itemData = event.data.item.data;
        var namespace = this.namespace;
        var viewAssetTypeURL = this._viewAssetTypeURL;

        if (itemData.action === 'openAssetTypesSelector') {
          var itemSelectorDialog = new _frontendJsWeb.ItemSelectorDialog({
            eventName: namespace + 'selectAssetType',
            singleSelect: true,
            title: Liferay.Language.get('select-asset-type'),
            url: this._selectAssetTypeURL
          });
          itemSelectorDialog.open();
          itemSelectorDialog.on('selectedItemChange', function (event) {
            var selectedItem = event.selectedItem;

            if (selectedItem) {
              var uri = viewAssetTypeURL;
              uri = (0, _frontendJsWeb.addParams)(namespace + 'className=' + selectedItem.value, uri);
              location.href = uri;
            }
          });
        }
      }
    }]);

    return SharedAssets;
  }(_frontendJsWeb.PortletBase);

  var _default = SharedAssets;
  exports["default"] = _default;
  //# sourceMappingURL=SharedAssets.es.js.map
});
//# sourceMappingURL=SharedAssets.es.js.map
